@@ -25,7 +25,7 @@ DEALINGS IN THE SOFTWARE.
 
 # If you're wondering why this is essentially copy pasted from the async_.py
 # file, then it's due to needing two separate types to make the typing shenanigans
-# a bit easier to write. It's an unfortunate design. originallyy, these types were
+# a bit easier to write. It's an unfortunate design. Originally, these types were
 # merged and an adapter was used to differentiate between the async and sync versions.
 # However, this proved to be difficult to provide typings for, so here we are.
 
@@ -37,19 +37,7 @@ import re
 import threading
 import time
 import weakref
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Dict,
-    List,
-    Literal,
-    Optional,
-    Tuple,
-    Type,
-    TypeVar,
-    Union,
-    overload,
-)
+from typing import TYPE_CHECKING, Any, Literal, overload
 from urllib.parse import quote as urlquote
 
 from .. import utils
@@ -92,7 +80,7 @@ MISSING = utils.MISSING
 class DeferredLock:
     def __init__(self, lock: threading.Lock):
         self.lock = lock
-        self.delta: Optional[float] = None
+        self.delta: float | None = None
 
     def __enter__(self):
         self.lock.acquire()
@@ -116,16 +104,16 @@ class WebhookAdapter:
         route: Route,
         session: Session,
         *,
-        payload: Optional[Dict[str, Any]] = None,
-        multipart: Optional[List[Dict[str, Any]]] = None,
-        files: Optional[List[File]] = None,
-        reason: Optional[str] = None,
-        auth_token: Optional[str] = None,
-        params: Optional[Dict[str, Any]] = None,
+        payload: dict[str, Any] | None = None,
+        multipart: list[dict[str, Any]] | None = None,
+        files: list[File] | None = None,
+        reason: str | None = None,
+        auth_token: str | None = None,
+        params: dict[str, Any] | None = None,
     ) -> Any:
-        headers: Dict[str, str] = {}
+        headers: dict[str, str] = {}
         files = files or []
-        to_send: Optional[Union[str, Dict[str, Any]]] = None
+        to_send: str | dict[str, Any] | None = None
         bucket = (route.webhook_id, route.webhook_token)
 
         try:
@@ -143,9 +131,9 @@ class WebhookAdapter:
         if reason is not None:
             headers["X-Audit-Log-Reason"] = urlquote(reason, safe="/ ")
 
-        response: Optional[Response] = None
-        data: Optional[Union[Dict[str, Any], str]] = None
-        file_data: Optional[Dict[str, Any]] = None
+        response: Response | None = None
+        data: dict[str, Any] | str | None = None
+        file_data: dict[str, Any] | None = None
         method = route.method
         url = route.url
         webhook_id = route.webhook_id
@@ -189,7 +177,10 @@ class WebhookAdapter:
                         response.status = response.status_code  # type: ignore
 
                         data = response.text or None
-                        if data and response.headers["Content-Type"] == "application/json":
+                        if (
+                            data
+                            and response.headers["Content-Type"] == "application/json"
+                        ):
                             data = json.loads(data)
 
                         remaining = response.headers.get("X-Ratelimit-Remaining")
@@ -246,9 +237,9 @@ class WebhookAdapter:
         self,
         webhook_id: int,
         *,
-        token: Optional[str] = None,
+        token: str | None = None,
         session: Session,
-        reason: Optional[str] = None,
+        reason: str | None = None,
     ):
         route = Route("DELETE", "/webhooks/{webhook_id}", webhook_id=webhook_id)
         return self.request(route, session, reason=reason, auth_token=token)
@@ -259,7 +250,7 @@ class WebhookAdapter:
         token: str,
         *,
         session: Session,
-        reason: Optional[str] = None,
+        reason: str | None = None,
     ):
         route = Route(
             "DELETE",
@@ -273,22 +264,24 @@ class WebhookAdapter:
         self,
         webhook_id: int,
         token: str,
-        payload: Dict[str, Any],
+        payload: dict[str, Any],
         *,
         session: Session,
-        reason: Optional[str] = None,
+        reason: str | None = None,
     ):
         route = Route("PATCH", "/webhooks/{webhook_id}", webhook_id=webhook_id)
-        return self.request(route, session, reason=reason, payload=payload, auth_token=token)
+        return self.request(
+            route, session, reason=reason, payload=payload, auth_token=token
+        )
 
     def edit_webhook_with_token(
         self,
         webhook_id: int,
         token: str,
-        payload: Dict[str, Any],
+        payload: dict[str, Any],
         *,
         session: Session,
-        reason: Optional[str] = None,
+        reason: str | None = None,
     ):
         route = Route(
             "PATCH",
@@ -304,11 +297,11 @@ class WebhookAdapter:
         token: str,
         *,
         session: Session,
-        payload: Optional[Dict[str, Any]] = None,
-        multipart: Optional[List[Dict[str, Any]]] = None,
-        files: Optional[List[File]] = None,
-        thread_id: Optional[int] = None,
-        thread_name: Optional[str] = None,
+        payload: dict[str, Any] | None = None,
+        multipart: list[dict[str, Any]] | None = None,
+        files: list[File] | None = None,
+        thread_id: int | None = None,
+        thread_name: str | None = None,
         wait: bool = False,
     ):
         params = {"wait": int(wait)}
@@ -340,7 +333,7 @@ class WebhookAdapter:
         message_id: int,
         *,
         session: Session,
-        thread_id: Optional[int] = None,
+        thread_id: int | None = None,
     ):
         params = {}
 
@@ -363,10 +356,10 @@ class WebhookAdapter:
         message_id: int,
         *,
         session: Session,
-        thread_id: Optional[int] = None,
-        payload: Optional[Dict[str, Any]] = None,
-        multipart: Optional[List[Dict[str, Any]]] = None,
-        files: Optional[List[File]] = None,
+        thread_id: int | None = None,
+        payload: dict[str, Any] | None = None,
+        multipart: list[dict[str, Any]] | None = None,
+        files: list[File] | None = None,
     ):
         params = {}
 
@@ -396,7 +389,7 @@ class WebhookAdapter:
         message_id: int,
         *,
         session: Session,
-        thread_id: Optional[int] = None,
+        thread_id: int | None = None,
     ):
         params = {}
 
@@ -439,7 +432,7 @@ class WebhookAdapter:
 
 
 class _WebhookContext(threading.local):
-    adapter: Optional[WebhookAdapter] = None
+    adapter: WebhookAdapter | None = None
 
 
 _context = _WebhookContext()
@@ -467,17 +460,17 @@ class SyncWebhookMessage(Message):
 
     def edit(
         self,
-        content: Optional[str] = MISSING,
-        embeds: List[Embed] = MISSING,
-        embed: Optional[Embed] = MISSING,
+        content: str | None = MISSING,
+        embeds: list[Embed] = MISSING,
+        embed: Embed | None = MISSING,
         file: File = MISSING,
-        files: List[File] = MISSING,
-        allowed_mentions: Optional[AllowedMentions] = None,
+        files: list[File] = MISSING,
+        allowed_mentions: AllowedMentions | None = None,
     ) -> SyncWebhookMessage:
         """Edits the message.
 
         Parameters
-        ------------
+        ----------
         content: Optional[:class:`str`]
             The content to edit the message with or ``None`` to clear it.
         embeds: List[:class:`Embed`]
@@ -494,8 +487,13 @@ class SyncWebhookMessage(Message):
             Controls the mentions being processed in this message.
             See :meth:`.abc.Messageable.send` for more information.
 
-        Raises
+        Returns
         -------
+        :class:`SyncWebhookMessage`
+            The newly edited message.
+
+        Raises
+        ------
         HTTPException
             Editing the message failed.
         Forbidden
@@ -506,11 +504,6 @@ class SyncWebhookMessage(Message):
             The length of ``embeds`` was invalid
         InvalidArgument
             There was no token associated with this webhook.
-
-        Returns
-        --------
-        :class:`SyncWebhookMessage`
-            The newly edited message.
         """
         thread = MISSING
         if hasattr(self, "_thread_id"):
@@ -529,11 +522,11 @@ class SyncWebhookMessage(Message):
             thread=thread,
         )
 
-    def delete(self, *, delay: Optional[float] = None) -> None:
+    def delete(self, *, delay: float | None = None) -> None:
         """Deletes the message.
 
         Parameters
-        -----------
+        ----------
         delay: Optional[:class:`float`]
             If provided, the number of seconds to wait before deleting the message.
             This blocks the thread.
@@ -548,7 +541,7 @@ class SyncWebhookMessage(Message):
             Deleting the message failed.
         """
 
-        thread_id: Optional[int] = None
+        thread_id: int | None = None
         if hasattr(self, "_thread_id"):
             thread_id = self._thread_id
         elif isinstance(self.channel, Thread):
@@ -577,13 +570,13 @@ class SyncWebhook(BaseWebhook):
 
         .. describe:: hash(x)
 
-            Returns the webhooks's hash.
+            Returns the webhook's hash.
 
     .. versionchanged:: 1.4
         Webhooks are now comparable and hashable.
 
     Attributes
-    ------------
+    ----------
     id: :class:`int`
         The webhook's ID
     type: :class:`WebhookType`
@@ -616,13 +609,13 @@ class SyncWebhook(BaseWebhook):
         .. versionadded:: 2.0
     """
 
-    __slots__: Tuple[str, ...] = ("session",)
+    __slots__: tuple[str, ...] = ("session",)
 
     def __init__(
         self,
         data: WebhookPayload,
         session: Session,
-        token: Optional[str] = None,
+        token: str | None = None,
         state=None,
     ):
         super().__init__(data, token, state)
@@ -643,12 +636,12 @@ class SyncWebhook(BaseWebhook):
         token: str,
         *,
         session: Session = MISSING,
-        bot_token: Optional[str] = None,
+        bot_token: str | None = None,
     ) -> SyncWebhook:
         """Creates a partial :class:`Webhook`.
 
         Parameters
-        -----------
+        ----------
         id: :class:`int`
             The ID of the webhook.
         token: :class:`str`
@@ -663,7 +656,7 @@ class SyncWebhook(BaseWebhook):
             involving the webhook.
 
         Returns
-        --------
+        -------
         :class:`Webhook`
             A partial :class:`Webhook`.
             A partial webhook is just a webhook object with an ID and a token.
@@ -682,11 +675,13 @@ class SyncWebhook(BaseWebhook):
         return cls(data, session, token=bot_token)
 
     @classmethod
-    def from_url(cls, url: str, *, session: Session = MISSING, bot_token: Optional[str] = None) -> SyncWebhook:
+    def from_url(
+        cls, url: str, *, session: Session = MISSING, bot_token: str | None = None
+    ) -> SyncWebhook:
         """Creates a partial :class:`Webhook` from a webhook URL.
 
         Parameters
-        ------------
+        ----------
         url: :class:`str`
             The URL of the webhook.
         session: :class:`requests.Session`
@@ -698,16 +693,16 @@ class SyncWebhook(BaseWebhook):
             The bot authentication token for authenticated requests
             involving the webhook.
 
-        Raises
-        -------
-        InvalidArgument
-            The URL is invalid.
-
         Returns
-        --------
+        -------
         :class:`Webhook`
             A partial :class:`Webhook`.
             A partial webhook is just a webhook object with an ID and a token.
+
+        Raises
+        ------
+        InvalidArgument
+            The URL is invalid.
         """
         m = re.search(
             r"discord(?:app)?.com/api/webhooks/(?P<id>\d{17,20})/(?P<token>[\w\.\-_]{60,68})",
@@ -716,7 +711,7 @@ class SyncWebhook(BaseWebhook):
         if m is None:
             raise InvalidArgument("Invalid webhook URL given.")
 
-        data: Dict[str, Any] = m.groupdict()
+        data: dict[str, Any] = m.groupdict()
         data["type"] = 1
         import requests
 
@@ -738,41 +733,45 @@ class SyncWebhook(BaseWebhook):
             returned webhook does not contain any user information.
 
         Parameters
-        -----------
+        ----------
         prefer_auth: :class:`bool`
             Whether to use the bot token over the webhook token
             if available. Defaults to ``True``.
 
-        Raises
+        Returns
         -------
+        :class:`SyncWebhook`
+            The fetched webhook.
+
+        Raises
+        ------
         HTTPException
             Could not fetch the webhook
         NotFound
             Could not find the webhook by this ID
         InvalidArgument
             This webhook does not have a token associated with it.
-
-        Returns
-        --------
-        :class:`SyncWebhook`
-            The fetched webhook.
         """
         adapter: WebhookAdapter = _get_webhook_adapter()
 
         if prefer_auth and self.auth_token:
             data = adapter.fetch_webhook(self.id, self.auth_token, session=self.session)
         elif self.token:
-            data = adapter.fetch_webhook_with_token(self.id, self.token, session=self.session)
+            data = adapter.fetch_webhook_with_token(
+                self.id, self.token, session=self.session
+            )
         else:
-            raise InvalidArgument("This webhook does not have a token associated with it")
+            raise InvalidArgument(
+                "This webhook does not have a token associated with it"
+            )
 
         return SyncWebhook(data, self.session, token=self.auth_token, state=self._state)
 
-    def delete(self, *, reason: Optional[str] = None, prefer_auth: bool = True) -> None:
+    def delete(self, *, reason: str | None = None, prefer_auth: bool = True) -> None:
         """Deletes this Webhook.
 
         Parameters
-        ------------
+        ----------
         reason: Optional[:class:`str`]
             The reason for deleting this webhook. Shows up on the audit log.
 
@@ -782,7 +781,7 @@ class SyncWebhook(BaseWebhook):
             if available. Defaults to ``True``.
 
         Raises
-        -------
+        ------
         HTTPException
             Deleting the webhook failed.
         NotFound
@@ -793,28 +792,34 @@ class SyncWebhook(BaseWebhook):
             This webhook does not have a token associated with it.
         """
         if self.token is None and self.auth_token is None:
-            raise InvalidArgument("This webhook does not have a token associated with it")
+            raise InvalidArgument(
+                "This webhook does not have a token associated with it"
+            )
 
         adapter: WebhookAdapter = _get_webhook_adapter()
 
         if prefer_auth and self.auth_token:
-            adapter.delete_webhook(self.id, token=self.auth_token, session=self.session, reason=reason)
+            adapter.delete_webhook(
+                self.id, token=self.auth_token, session=self.session, reason=reason
+            )
         elif self.token:
-            adapter.delete_webhook_with_token(self.id, self.token, session=self.session, reason=reason)
+            adapter.delete_webhook_with_token(
+                self.id, self.token, session=self.session, reason=reason
+            )
 
     def edit(
         self,
         *,
-        reason: Optional[str] = None,
-        name: Optional[str] = MISSING,
-        avatar: Optional[bytes] = MISSING,
-        channel: Optional[Snowflake] = None,
+        reason: str | None = None,
+        name: str | None = MISSING,
+        avatar: bytes | None = MISSING,
+        channel: Snowflake | None = None,
         prefer_auth: bool = True,
     ) -> SyncWebhook:
         """Edits this Webhook.
 
         Parameters
-        ------------
+        ----------
         name: Optional[:class:`str`]
             The webhook's new default name.
         avatar: Optional[:class:`bytes`]
@@ -829,34 +834,38 @@ class SyncWebhook(BaseWebhook):
             Whether to use the bot token over the webhook token
             if available. Defaults to ``True``.
 
-        Raises
+        Returns
         -------
+        :class:`SyncWebhook`
+            The newly edited webhook.
+
+        Raises
+        ------
         HTTPException
             Editing the webhook failed.
         NotFound
             This webhook does not exist.
         InvalidArgument
-            This webhook does not have a token associated with it
-            or it tried editing a channel without authentication.
-
-        Returns
-        --------
-        :class:`SyncWebhook`
-            The newly edited webhook.
+            This webhook does not have a token associated with it, or
+            it tried editing a channel without authentication.
         """
         if self.token is None and self.auth_token is None:
-            raise InvalidArgument("This webhook does not have a token associated with it")
+            raise InvalidArgument(
+                "This webhook does not have a token associated with it"
+            )
 
         payload = {}
         if name is not MISSING:
             payload["name"] = str(name) if name is not None else None
 
         if avatar is not MISSING:
-            payload["avatar"] = utils._bytes_to_base64_data(avatar) if avatar is not None else None
+            payload["avatar"] = (
+                utils._bytes_to_base64_data(avatar) if avatar is not None else None
+            )
 
         adapter: WebhookAdapter = _get_webhook_adapter()
 
-        data: Optional[WebhookPayload] = None
+        data: WebhookPayload | None = None
         # If a channel is given, always use the authenticated endpoint
         if channel is not None:
             if self.auth_token is None:
@@ -891,7 +900,9 @@ class SyncWebhook(BaseWebhook):
         if data is None:
             raise RuntimeError("Unreachable code hit: data was not assigned")
 
-        return SyncWebhook(data=data, session=self.session, token=self.auth_token, state=self._state)
+        return SyncWebhook(
+            data=data, session=self.session, token=self.auth_token, state=self._state
+        )
 
     def _create_message(self, data):
         state = _WebhookState(self, parent=self._state)
@@ -909,12 +920,12 @@ class SyncWebhook(BaseWebhook):
         avatar_url: Any = MISSING,
         tts: bool = MISSING,
         file: File = MISSING,
-        files: List[File] = MISSING,
+        files: list[File] = MISSING,
         embed: Embed = MISSING,
-        embeds: List[Embed] = MISSING,
+        embeds: list[Embed] = MISSING,
         allowed_mentions: AllowedMentions = MISSING,
         thread: Snowflake = MISSING,
-        thread_name: Optional[str] = None,
+        thread_name: str | None = None,
         wait: Literal[True],
     ) -> SyncWebhookMessage:
         ...
@@ -928,12 +939,12 @@ class SyncWebhook(BaseWebhook):
         avatar_url: Any = MISSING,
         tts: bool = MISSING,
         file: File = MISSING,
-        files: List[File] = MISSING,
+        files: list[File] = MISSING,
         embed: Embed = MISSING,
-        embeds: List[Embed] = MISSING,
+        embeds: list[Embed] = MISSING,
         allowed_mentions: AllowedMentions = MISSING,
         thread: Snowflake = MISSING,
-        thread_name: Optional[str] = None,
+        thread_name: str | None = None,
         wait: Literal[False] = ...,
     ) -> None:
         ...
@@ -946,14 +957,14 @@ class SyncWebhook(BaseWebhook):
         avatar_url: Any = MISSING,
         tts: bool = False,
         file: File = MISSING,
-        files: List[File] = MISSING,
+        files: list[File] = MISSING,
         embed: Embed = MISSING,
-        embeds: List[Embed] = MISSING,
+        embeds: list[Embed] = MISSING,
         allowed_mentions: AllowedMentions = MISSING,
         thread: Snowflake = MISSING,
-        thread_name: Optional[str] = None,
+        thread_name: str | None = None,
         wait: bool = False,
-    ) -> Optional[SyncWebhookMessage]:
+    ) -> SyncWebhookMessage | None:
         """Sends a message using the webhook.
 
         The content must be a type that can convert to a string through ``str(content)``.
@@ -1006,6 +1017,11 @@ class SyncWebhook(BaseWebhook):
 
             .. versionadded:: 2.0
 
+        Returns
+        -------
+        Optional[:class:`SyncWebhookMessage`]
+            If ``wait`` is ``True`` then the message that was sent, otherwise ``None``.
+
         Raises
         ------
         HTTPException
@@ -1019,19 +1035,18 @@ class SyncWebhook(BaseWebhook):
         ValueError
             The length of ``embeds`` was invalid
         InvalidArgument
-            There was no token associated with this webhook or you specified both
+            There was no token associated with this webhook, or you specified both
             a thread to send to and a thread to create (the ``thread`` and ``thread_name`` parameters).
-
-        Returns
-        -------
-        Optional[:class:`SyncWebhookMessage`]
-            If ``wait`` is ``True`` then the message that was sent, otherwise ``None``.
         """
 
         if self.token is None:
-            raise InvalidArgument("This webhook does not have a token associated with it")
+            raise InvalidArgument(
+                "This webhook does not have a token associated with it"
+            )
 
-        previous_mentions: Optional[AllowedMentions] = getattr(self._state, "allowed_mentions", None)
+        previous_mentions: AllowedMentions | None = getattr(
+            self._state, "allowed_mentions", None
+        )
         if content is None:
             content = MISSING
 
@@ -1051,7 +1066,7 @@ class SyncWebhook(BaseWebhook):
             previous_allowed_mentions=previous_mentions,
         )
         adapter: WebhookAdapter = _get_webhook_adapter()
-        thread_id: Optional[int] = None
+        thread_id: int | None = None
         if thread is not MISSING:
             thread_id = thread.id
 
@@ -1069,20 +1084,27 @@ class SyncWebhook(BaseWebhook):
         if wait:
             return self._create_message(data)
 
-    def fetch_message(self, id: int, *, thread_id: Optional[int] = None) -> SyncWebhookMessage:
+    def fetch_message(
+        self, id: int, *, thread_id: int | None = None
+    ) -> SyncWebhookMessage:
         """Retrieves a single :class:`~discord.SyncWebhookMessage` owned by this webhook.
 
         .. versionadded:: 2.0
 
         Parameters
-        ------------
+        ----------
         id: :class:`int`
             The message ID to look for.
         thread_id: Optional[:class:`int`]
             The ID of the thread that contains the message.
 
+        Returns
+        -------
+        :class:`~discord.SyncWebhookMessage`
+            The message asked for.
+
         Raises
-        --------
+        ------
         ~discord.NotFound
             The specified message was not found.
         ~discord.Forbidden
@@ -1091,15 +1113,12 @@ class SyncWebhook(BaseWebhook):
             Retrieving the message failed.
         InvalidArgument
             There was no token associated with this webhook.
-
-        Returns
-        --------
-        :class:`~discord.SyncWebhookMessage`
-            The message asked for.
         """
 
         if self.token is None:
-            raise InvalidArgument("This webhook does not have a token associated with it")
+            raise InvalidArgument(
+                "This webhook does not have a token associated with it"
+            )
 
         adapter: WebhookAdapter = _get_webhook_adapter()
         data = adapter.get_webhook_message(
@@ -1119,13 +1138,13 @@ class SyncWebhook(BaseWebhook):
         self,
         message_id: int,
         *,
-        content: Optional[str] = MISSING,
-        embeds: List[Embed] = MISSING,
-        embed: Optional[Embed] = MISSING,
+        content: str | None = MISSING,
+        embeds: list[Embed] = MISSING,
+        embed: Embed | None = MISSING,
         file: File = MISSING,
-        files: List[File] = MISSING,
-        allowed_mentions: Optional[AllowedMentions] = None,
-        thread: Optional[Snowflake] = MISSING,
+        files: list[File] = MISSING,
+        allowed_mentions: AllowedMentions | None = None,
+        thread: Snowflake | None = MISSING,
     ) -> SyncWebhookMessage:
         """Edits a message owned by this webhook.
 
@@ -1135,7 +1154,7 @@ class SyncWebhook(BaseWebhook):
         .. versionadded:: 1.6
 
         Parameters
-        ------------
+        ----------
         message_id: :class:`int`
             The message ID to edit.
         content: Optional[:class:`str`]
@@ -1157,7 +1176,7 @@ class SyncWebhook(BaseWebhook):
             The thread that contains the message.
 
         Raises
-        -------
+        ------
         HTTPException
             Editing the message failed.
         Forbidden
@@ -1171,9 +1190,13 @@ class SyncWebhook(BaseWebhook):
         """
 
         if self.token is None:
-            raise InvalidArgument("This webhook does not have a token associated with it")
+            raise InvalidArgument(
+                "This webhook does not have a token associated with it"
+            )
 
-        previous_mentions: Optional[AllowedMentions] = getattr(self._state, "allowed_mentions", None)
+        previous_mentions: AllowedMentions | None = getattr(
+            self._state, "allowed_mentions", None
+        )
         params = handle_message_parameters(
             content=content,
             file=file,
@@ -1185,7 +1208,7 @@ class SyncWebhook(BaseWebhook):
         )
         adapter: WebhookAdapter = _get_webhook_adapter()
 
-        thread_id: Optional[int] = None
+        thread_id: int | None = None
         if thread is not MISSING:
             thread_id = thread.id
 
@@ -1201,7 +1224,7 @@ class SyncWebhook(BaseWebhook):
         )
         return self._create_message(data)
 
-    def delete_message(self, message_id: int, *, thread_id: Optional[int] = None) -> None:
+    def delete_message(self, message_id: int, *, thread_id: int | None = None) -> None:
         """Deletes a message owned by this webhook.
 
         This is a lower level interface to :meth:`WebhookMessage.delete` in case
@@ -1210,21 +1233,23 @@ class SyncWebhook(BaseWebhook):
         .. versionadded:: 1.6
 
         Parameters
-        ------------
+        ----------
         message_id: :class:`int`
             The message ID to delete.
         thread_id: Optional[:class:`int`]
             The ID of the thread that contains the message.
 
         Raises
-        -------
+        ------
         HTTPException
             Deleting the message failed.
         Forbidden
             Deleted a message that is not yours.
         """
         if self.token is None:
-            raise InvalidArgument("This webhook does not have a token associated with it")
+            raise InvalidArgument(
+                "This webhook does not have a token associated with it"
+            )
 
         adapter: WebhookAdapter = _get_webhook_adapter()
         adapter.delete_webhook_message(
