@@ -77,7 +77,8 @@ class BaseMESSAGE:
         "update_semaphore",
         "parent",
         "remove_after",
-        "_created_at"
+        "_created_at",
+        "_deleted"
     )
 
     @typechecked
@@ -126,11 +127,12 @@ class BaseMESSAGE:
         self._created_at = datetime.now()
         self._data = data
         self._fbcdata = isinstance(data, _FunctionBaseCLASS)
+        self._deleted = False
         # Attributes created with this function will not be re-referenced to a different object
         # if the function is called again, ensuring safety (.update_method)
         misc._write_attr_once(self, "update_semaphore", asyncio.Semaphore(1))
         # For comparing copies of the object (prevents .update from overwriting)
-        misc._write_attr_once(self, "_id", id(self)) 
+        misc._write_attr_once(self, "_id", id(self))
 
     def __repr__(self) -> str:
         return f"{type(self).__name__}(data={self._data})"
@@ -174,6 +176,26 @@ class BaseMESSAGE:
         "Returns the datetime of when the object was created"
         return self._created_at
 
+    @property
+    def deleted(self) -> bool:
+        """
+        Returns
+        -----------
+        True
+            The object is no longer in the framework and should no longer
+            be used.
+        False
+            Object is in the framework in normal operation.
+        """
+        return self._deleted
+    
+    def _delete(self):
+        """
+        Sets the internal _deleted flag to True,
+        indicating the object should not be used.
+        """
+        self._deleted = True
+
     def _check_state(self) -> bool:
         """
         Checks if the message is ready to be deleted.
