@@ -716,15 +716,6 @@ class DirectMESSAGE(BaseMESSAGE):
                 if ex.code == 10008:    # Unknown message
                     self.previous_message = None
                     handled = True
-            elif ex.status == 403 or ex.code in {50007, 10001, 10003}:
-                # Not permitted to send messages to that user!
-                # Remove all messages to prevent an account ban
-                for m in self.parent.messages:
-                    if m in self.parent.messages:
-                        self.parent.remove_message(m)
-
-            if ex.status in {400, 403}: # Bad Request
-                await asyncio.sleep(RLIM_USER_WAIT_TIME) # To avoid triggering self-bot detection
 
         return handled
 
@@ -772,19 +763,22 @@ class DirectMESSAGE(BaseMESSAGE):
 
         Returns
         ----------
-        Union[Dict, None]
-            Returns a dictionary generated by the ``generate_log_context`` method or the None object if message wasn't ready to be sent (:ref:`data_function` returned None or an invalid type)
-
-            This is then passed to :ref:`GUILD`._generate_log method.
+        Tuple[Union[dict, None], bool]
+            Returns a tuple of logging context and bool
+            variable that signals the upper layer all other messages should be removed
+            due to a forbidden error which automatically causes other messages to fail
+            and increases risk of getting a user account banned.
         """
         # Parse data from the data parameter
         data_to_send = await self._get_data()
+        context, panic = None, False
         if any(data_to_send.values()):            
             context = await self._send_channel(**data_to_send)
             self._update_state()
-            return self.generate_log_context(context, **data_to_send)
+            panic = ("reason" in context and context["reason"].status in {400, 403})
+            context = self.generate_log_context(context, **data_to_send)
 
-        return None
+        return context, panic
 
     @typechecked
     @misc._async_safe("update_semaphore")
